<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>mxselectsound</name>
    <message>
        <location filename="../mxselectsound.ui" line="14"/>
        <location filename="../mxselectsound.cpp" line="47"/>
        <location filename="../mxselectsound.cpp" line="77"/>
        <location filename="../mxselectsound.cpp" line="135"/>
        <location filename="../mxselectsound.cpp" line="147"/>
        <location filename="../mxselectsound.cpp" line="181"/>
        <location filename="../mxselectsound.cpp" line="190"/>
        <source>MX Select Sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxselectsound.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your current default sound card is:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxselectsound.ui" line="64"/>
        <source>Display help </source>
        <translation>Súgó megjelenítése</translation>
    </message>
    <message>
        <location filename="../mxselectsound.ui" line="67"/>
        <source>Help</source>
        <translation>Súgó</translation>
    </message>
    <message>
        <location filename="../mxselectsound.ui" line="75"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxselectsound.ui" line="104"/>
        <source>About this application</source>
        <translation>Az alkalmazásról</translation>
    </message>
    <message>
        <location filename="../mxselectsound.ui" line="107"/>
        <source>About...</source>
        <translation>Névjegy</translation>
    </message>
    <message>
        <location filename="../mxselectsound.ui" line="115"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxselectsound.ui" line="147"/>
        <source>Quit application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxselectsound.ui" line="150"/>
        <source>Close</source>
        <translation>Bezár</translation>
    </message>
    <message>
        <location filename="../mxselectsound.ui" line="158"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxselectsound.ui" line="199"/>
        <source>Apply</source>
        <translation>Alkamaz</translation>
    </message>
    <message>
        <location filename="../mxselectsound.ui" line="222"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select another sound card if necessary:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxselectsound.ui" line="248"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If your computer has more than one sound card, you can use this application to select the one to be default. &lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxselectsound.ui" line="294"/>
        <source>Test current sound card</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxselectsound.cpp" line="78"/>
        <source>No sound cards/devices were found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxselectsound.cpp" line="90"/>
        <location filename="../mxselectsound.cpp" line="104"/>
        <source>none</source>
        <translation>nincs</translation>
    </message>
    <message>
        <location filename="../mxselectsound.cpp" line="134"/>
        <source>About MX Select Sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxselectsound.cpp" line="135"/>
        <source>Version: </source>
        <translation>Verzió:</translation>
    </message>
    <message>
        <location filename="../mxselectsound.cpp" line="136"/>
        <source>Program for selecting the default sound card in MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxselectsound.cpp" line="138"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxselectsound.cpp" line="139"/>
        <location filename="../mxselectsound.cpp" line="147"/>
        <source>License</source>
        <translation>Liszensz</translation>
    </message>
    <message>
        <location filename="../mxselectsound.cpp" line="140"/>
        <source>Changelog</source>
        <translation>Változásbejegyzés</translation>
    </message>
    <message>
        <location filename="../mxselectsound.cpp" line="141"/>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../mxselectsound.cpp" line="156"/>
        <source>&amp;Close</source>
        <translation>&amp;Bezár</translation>
    </message>
    <message>
        <location filename="../mxselectsound.cpp" line="191"/>
        <source>Could not play test sound.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
